<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nb">
<context>
    <name>Batchprocessing</name>
    <message>
        <location filename="../src/batchprocessing.cpp" line="44"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="45"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation>Den gjeldende kjernen støtter ikke valgt komprimeringsalgoritme. Rediger oppsettsfila og velg en annen algoritme.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="70"/>
        <source>The program will pause the build and open the boot menu in your text editor.</source>
        <translation>Programmet vil pause generering og åpne oppstartsmenyen i et tekstprogram.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="100"/>
        <source>This computer uses an NVIDIA graphics card. Are you planning to use the resulting ISO on the same computer or another computer with an NVIDIA card?</source>
        <translation>Denne datamaskinen bruker et grafikkort fra NVIDIA. Skal ISO-bildet brukes på denne maskinen, eller en annen maskin med NVIDIA-kort?</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="110"/>
        <source>Note: If you use the resulting ISO on a computer without an NVIDIA card, you will likely need to remove &apos;xorg=nvidia&apos; from the boot options.</source>
        <translation>Merknad: Oppstartsalternativet &apos;xorg=nvidia&apos; må sannsynligvis fjernes hvis ISO-bildet skal brukes på en datamaskin uten NVIDIA-kort.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="113"/>
        <source>Note: If you use the resulting ISO on a computer with an NVIDIA card, you may need to add &apos;xorg=nvidia&apos; to the boot options.</source>
        <translation>Merknad: Oppstartsalternativet &apos;xorg=nvidia&apos; må sannsynligvis legges til hvis ISO-bilde skal brukes på en datamaskin med NVIDIA-kort.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="14"/>
        <location filename="../src/ui_mainwindow.h" line="721"/>
        <location filename="../src/mainwindow.cpp" line="182"/>
        <location filename="../src/mainwindow.cpp" line="516"/>
        <source>MX Snapshot</source>
        <translation>MX ISO-bilde</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="33"/>
        <location filename="../src/ui_mainwindow.h" line="722"/>
        <source>Optional customization</source>
        <translation>Valgfri tilpasning</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="65"/>
        <location filename="../src/ui_mainwindow.h" line="723"/>
        <source>Release version:</source>
        <translation>Utgitt versjon:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="79"/>
        <location filename="../src/ui_mainwindow.h" line="724"/>
        <source>Boot options:</source>
        <translation>Oppstartsalternativer:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="86"/>
        <location filename="../src/ui_mainwindow.h" line="725"/>
        <source>Live kernel:</source>
        <translation>Live-kjerne:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="93"/>
        <location filename="../src/ui_mainwindow.h" line="726"/>
        <source>Project name:</source>
        <translation>Prosjektnavn:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="100"/>
        <location filename="../src/ui_mainwindow.h" line="727"/>
        <source>Release date:</source>
        <translation>Utgivelsesdato:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="107"/>
        <location filename="../src/ui_mainwindow.h" line="728"/>
        <source>Release codename:</source>
        <translation>Utgivelsens kodenavn:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="133"/>
        <location filename="../src/ui_mainwindow.h" line="729"/>
        <source>Current date</source>
        <translation>Gjeldende dato</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="172"/>
        <location filename="../src/ui_mainwindow.h" line="730"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;ISO-bilde er et verktøy som kan lage en oppstartbar avbildning (ISO) av systemet, som kan brukes som reservekopi eller til videreformidling. Programmer som bruker små systemressurser kan fortsette å kjøre mens dette verktøyet arbeider.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="182"/>
        <location filename="../src/ui_mainwindow.h" line="731"/>
        <source>Used space on / (root) and /home partitions:</source>
        <translation>Brukt plass på / (rot-) og /home-partisjoner:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="192"/>
        <location filename="../src/ui_mainwindow.h" line="732"/>
        <source>Location and ISO name</source>
        <translation>Plassering og ISO-navn</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="219"/>
        <location filename="../src/ui_mainwindow.h" line="734"/>
        <source>Snapshot location:</source>
        <translation>Bildets plassering:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="226"/>
        <location filename="../src/ui_mainwindow.h" line="735"/>
        <source>Select a different snapshot directory</source>
        <translation>Velg en annen mappe for bildet</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="236"/>
        <location filename="../src/ui_mainwindow.h" line="736"/>
        <location filename="../src/mainwindow.cpp" line="371"/>
        <source>Snapshot name:</source>
        <translation>Bildets navn:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="360"/>
        <location filename="../src/ui_mainwindow.h" line="740"/>
        <source>Type of snapshot:</source>
        <translation>Type ISO-bilde:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="367"/>
        <location filename="../src/ui_mainwindow.h" line="741"/>
        <source>Preserving accounts (for personal backup)</source>
        <translation>Bevarer kontoer (for personlige reservekopier)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="377"/>
        <location filename="../src/ui_mainwindow.h" line="743"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the MX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Dette alternativet vil tilbakestille passordene til &amp;quot;demo&amp;quot; og &amp;quot;root&amp;quot; til sine MX Linux-forvalg, og vil ikke kopiere noen personlige kontoer som er opprettet.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="380"/>
        <location filename="../src/ui_mainwindow.h" line="745"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Tilbakestiller kontoer (for videreformidling til andre)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="451"/>
        <location filename="../src/ui_mainwindow.h" line="746"/>
        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /etc/mx-snapshot-exclude.list.</source>
        <translation>Mapper kan ekskluderes ved å velge dem nedenfor, eller ved å velge knappen for å selv redigere /etc/snapshot-exclude.list.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="496"/>
        <location filename="../src/ui_mainwindow.h" line="747"/>
        <source>sha512</source>
        <translation>sha512</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="519"/>
        <location filename="../src/ui_mainwindow.h" line="749"/>
        <source>Throttle the I/O input rate by the given percentage.</source>
        <translation>Strup I/U-forholdet med en gitt prosent.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="525"/>
        <location filename="../src/ui_mainwindow.h" line="751"/>
        <source>I/O throttle:</source>
        <translation>I/U-struping:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="532"/>
        <location filename="../src/ui_mainwindow.h" line="752"/>
        <source>Calculate checksums:</source>
        <translation>Beregn sjekksummer:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="539"/>
        <location filename="../src/ui_mainwindow.h" line="753"/>
        <source>ISO compression scheme:</source>
        <translation>Komprimeringstype for ISO:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="546"/>
        <location filename="../src/ui_mainwindow.h" line="754"/>
        <source>Number of CPU cores to use:</source>
        <translation>Antall CPU-kjerner å bruke:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="553"/>
        <location filename="../src/ui_mainwindow.h" line="755"/>
        <source>md5</source>
        <translation>md5</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="563"/>
        <location filename="../src/ui_mainwindow.h" line="756"/>
        <source>Options:</source>
        <translation>Valg:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="608"/>
        <location filename="../src/ui_mainwindow.h" line="757"/>
        <source>Edit Exclusion File</source>
        <translation>Rediger ekskluderingsfil</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="643"/>
        <location filename="../src/ui_mainwindow.h" line="758"/>
        <source>Pictures</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="650"/>
        <location filename="../src/ui_mainwindow.h" line="759"/>
        <source>Videos</source>
        <translation>Videoer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="657"/>
        <location filename="../src/ui_mainwindow.h" line="760"/>
        <source>All of the above</source>
        <translation>Alle over</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="664"/>
        <location filename="../src/ui_mainwindow.h" line="762"/>
        <source>exclude network configurations</source>
        <translation>ekskluder nettverksoppsett</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="667"/>
        <location filename="../src/ui_mainwindow.h" line="764"/>
        <source>Networks</source>
        <translation>Nettverk</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="674"/>
        <location filename="../src/ui_mainwindow.h" line="765"/>
        <source>Downloads</source>
        <translation>Nedlastinger</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="681"/>
        <location filename="../src/ui_mainwindow.h" line="766"/>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="688"/>
        <location filename="../src/ui_mainwindow.h" line="767"/>
        <source>Documents</source>
        <translation>Dokumenter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="695"/>
        <location filename="../src/ui_mainwindow.h" line="768"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="702"/>
        <location filename="../src/ui_mainwindow.h" line="769"/>
        <source>Music</source>
        <translation>Musikk</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="814"/>
        <location filename="../src/ui_mainwindow.h" line="772"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="817"/>
        <location filename="../src/ui_mainwindow.h" line="774"/>
        <source>About...</source>
        <translation>Om …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="823"/>
        <location filename="../src/ui_mainwindow.h" line="776"/>
        <source>Alt+B</source>
        <translation>Alt + B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="839"/>
        <location filename="../src/ui_mainwindow.h" line="778"/>
        <source>Next</source>
        <translation>Neste</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="864"/>
        <location filename="../src/ui_mainwindow.h" line="783"/>
        <source>Display help </source>
        <translation>Vis hjelp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="867"/>
        <location filename="../src/ui_mainwindow.h" line="785"/>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="873"/>
        <location filename="../src/ui_mainwindow.h" line="787"/>
        <source>Alt+H</source>
        <translation>Alt + H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="886"/>
        <location filename="../src/ui_mainwindow.h" line="790"/>
        <source>Quit application</source>
        <translation>Avslutt programmet</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="889"/>
        <location filename="../src/ui_mainwindow.h" line="792"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="895"/>
        <location filename="../src/ui_mainwindow.h" line="794"/>
        <source>Alt+N</source>
        <translation>Alt + N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="949"/>
        <location filename="../src/ui_mainwindow.h" line="797"/>
        <source>Back</source>
        <translation>Tilbake</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="144"/>
        <source>Select Release Date</source>
        <translation>Velg utgivelsesdato</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="188"/>
        <source>fastest, worst compression</source>
        <translation>raskest, dårligst komprimering</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="188"/>
        <source>fast, worse compression</source>
        <translation>rask, dårlig komprimering</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="189"/>
        <source>slow, better compression</source>
        <translation>treig, bedre komprimering</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="189"/>
        <source>best compromise</source>
        <translation>beste kompromiss</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="190"/>
        <source>slowest, best compression</source>
        <translation>treigeste, beste komprimering</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="219"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Ledig plass på %1, der mappa til ISO-bildet legges:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="222"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space by removing previous snapshots and saved copies: %1 snapshots are taking up %2 of disk space.</source>
        <translation>Det bør være nok ledig plass til de komprimerte dataene fra / og /home

    Hvis nødvendig så kan du frigjøre plass ved å
    fjerne gamle ISO-bilder og lagrede kopier:
    %1 ISO-bilder bruker %2 diskplass.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="234"/>
        <location filename="../src/mainwindow.cpp" line="235"/>
        <source>Installing </source>
        <translation>Installerer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="320"/>
        <source>Please wait.</source>
        <translation>Vennligst vent.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="322"/>
        <source>Please wait. Calculating used disk space...</source>
        <translation>Vennligst vent. Beregner brukt diskplass …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="356"/>
        <location filename="../src/mainwindow.cpp" line="413"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="357"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation>Utfila %1 finnes allerede. Velg et annet filnavn eller slett eksisterende fil.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="362"/>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="368"/>
        <source>Snapshot will use the following settings:</source>
        <translation>ISO-bilde vil bruke de følgende innstillingene:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="370"/>
        <source>- Snapshot directory:</source>
        <translation>– ISO-bildets mappe:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="371"/>
        <source>- Kernel to be used:</source>
        <translation>– Kjerne som skal brukes:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="393"/>
        <location filename="../src/mainwindow.cpp" line="402"/>
        <source>NVIDIA Detected</source>
        <translation>Oppdaget NVIDIA</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="394"/>
        <source>This computer uses an NVIDIA graphics card. Are you planning to use the resulting ISO on the same computer or another computer with an NVIDIA card?</source>
        <translation>Denne datamaskinen bruker et grafikkort fra NVIDIA. Skal ISO-bildet brukes på denne maskinen, eller en annen maskin med NVIDIA-kort?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="398"/>
        <source>NVIDIA Selected</source>
        <translation>NVIDIA er valgt</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="399"/>
        <source>Note: If you use the resulting ISO on a computer without an NVIDIA card, you will likely need to remove &apos;xorg=nvidia&apos; from the boot options.</source>
        <translation>Merknad: Oppstartsalternativet &apos;xorg=nvidia&apos; må sannsynligvis fjernes hvis ISO-bildet skal brukes på en datamaskin uten NVIDIA-kort.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="403"/>
        <source>Note: If you use the resulting ISO on a computer with an NVIDIA card, you may need to add &apos;xorg=nvidia&apos; to the boot options.</source>
        <translation>Merknad: Oppstartsalternativet &apos;xorg=nvidia&apos; må sannsynligvis legges til hvis ISO-bilde skal brukes på en datamaskin med NVIDIA-kort.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="414"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation>Den gjeldende kjernen støtter ikke valgt komprimeringsalgoritme. Rediger oppsettsfila og velg en annen algoritme.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="437"/>
        <source>Final chance</source>
        <translation>Siste sjanse</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="439"/>
        <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
        <translation>Programmet har nå all nødvendig informasjon for å kunne opprette et ISO-bilde av det kjørende systemet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="440"/>
        <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
        <translation>Dette vil ta noe tid, avhengig av størrelsen til det installerte systemet og hvor kraftig datamaskinen er.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="442"/>
        <source>OK to start?</source>
        <translation>Klar til start?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="446"/>
        <source>Shutdown computer when done.</source>
        <translation>Slå av datamaskinen ved fullføring.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="479"/>
        <source>Output</source>
        <translation>Utdata</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="495"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="502"/>
        <source>Edit Boot Menu</source>
        <translation>Rediger oppstartsmeny</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="503"/>
        <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
        <translation>Programmet vil nå pause slik at du kan redigere filer i arbeidsmappa. Velg «Ja» for å redigere oppstartsmenyen eller «Nei» for å hoppe over dette trinnet og fortsette med opprettelsen av ISO-bildet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="599"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="601"/>
        <source>Version: </source>
        <translation>Versjon:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="602"/>
        <source>Program for creating a live-CD from the running system for MX Linux</source>
        <translation>Program for å opprette en live-CD for det kjørende systemet, for MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="604"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Opphavsrett (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="606"/>
        <source>%1 License</source>
        <translation>Lisens for %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="620"/>
        <source>%1 Help</source>
        <translation>Hjelpetekst for %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="625"/>
        <source>Select Snapshot Directory</source>
        <translation>Velg mappe for ISO-bilde</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="646"/>
        <source>Confirmation</source>
        <translation>Bekreft</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="646"/>
        <source>Are you sure you want to quit the application?</source>
        <translation>Vil du virkelig avslutte dette programmet?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="77"/>
        <source>Tool used for creating a live-CD from the running system</source>
        <translation>Program for å opprette en live-CD for det kjørende systemet</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="81"/>
        <source>Use CLI only</source>
        <translation>Kun kommandolinje</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="85"/>
        <source>Number of CPU cores to be used.</source>
        <translation>Antall CPU-kjerner som skal brukes.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="86"/>
        <source>Output directory</source>
        <translation>Mappe med utdata</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="87"/>
        <source>Output filename</source>
        <translation>Utdatas filnavn</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="89"/>
        <source>Name a different kernel to use other than the default running kernel, use format returned by &apos;uname -r&apos;</source>
        <translation>Angi en annen kjerne enn den kjørende; bruk formatet gitt av &apos;uname -r&apos;</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="91"/>
        <source>Or the full path: %1</source>
        <translation>Eller full sti: %1</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="94"/>
        <source>Compression level options.</source>
        <translation>Velg komprimeringsnivå.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="95"/>
        <source>Use quotes: &quot;-Xcompression-level &lt;level&gt;&quot;, or &quot;-Xalgorithm &lt;algorithm&gt;&quot;, or &quot;-Xhc&quot;, see mksquashfs man page</source>
        <translation>Bruk sitattegn: &quot;-Xcompression-level &lt;level&gt;&quot; eller &quot;-Xalgoritm &lt;algorithm&gt;&quot; eller &quot;-Xhc&quot;, se man-siden til mksquashfs</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="99"/>
        <source>Create a monthly snapshot, add &apos;Month&apos; name in the ISO name, skip used space calculation</source>
        <translation>Lag et månedlig ISO-bilde. Legg til måneden i ISO-navnet og hopp over beregning av brukt plass.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="100"/>
        <source>This option sets reset-accounts and compression to defaults, arguments changing those items will be ignored</source>
        <translation>Dette alternativet tilbakestiller «reset-accounts» og «compression» til forvalgte verdier, og argumenter som endrer disse to vil bli ignorert</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="102"/>
        <source>Optionally specify a suffix to add to the month name (e.g., &apos;1&apos; for &apos;July.1&apos;)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main.cpp" line="103"/>
        <source>Don&apos;t calculate checksums for resulting ISO file</source>
        <translation>Ikke beregn sjekksummer for resulterende ISO-fil</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="104"/>
        <source>Skip calculating free space to see if the resulting ISO will fit</source>
        <translation>Hopp over beregning av ledig diskplass for å sjekke om resulterende ISO vil passe</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="105"/>
        <source>Option to fix issue with calculating checksums on preempt_rt kernels</source>
        <translation>Alternativ som løser et problem med beregning av sjekksummer på preempt_rt-kjerner</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="106"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Tilbakestiller kontoer (for videreformidling til andre)</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="107"/>
        <source>Calculate checksums for resulting ISO file</source>
        <translation>Beregn sjekksummer for resulterende ISO-fil</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="109"/>
        <source>Throttle the I/O input rate by the given percentage. This can be used to reduce the I/O and CPU consumption of Mksquashfs.</source>
        <translation>Strup I/U-forholdet med den gitte prosenten. Dette reduserer I/U- og CPU-forbruket til Mksquashfs.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>Work directory</source>
        <translation>Arbeidsmappe</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="114"/>
        <source>Exclude main folders, valid choices: </source>
        <translation>Utelat hovedmapper; gyldige alternativer:</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="116"/>
        <source>Use the option one time for each item you want to exclude</source>
        <translation>Bruk alternativet én gang for hvert element som skal utelates</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="119"/>
        <source>Compression format, valid choices: </source>
        <translation>Komprimeringsformat; gyldige alternativer:</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="121"/>
        <source>Shutdown computer when done.</source>
        <translation>Slå av datamaskinen ved fullføring.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="170"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du er innlogget som root. Vennligst logg ut, og logg inn igjen som en vanlig bruker for å bruke dette programmet.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="188"/>
        <source>version:</source>
        <translation>versjon:</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="182"/>
        <source>You must run this program with sudo or pkexec.</source>
        <translation>Dette programmet må kjøres med sudo eller pkexec.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="165"/>
        <source>MX Snapshot</source>
        <translation>MX ISO-bilde</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="453"/>
        <location filename="../src/settings.cpp" line="461"/>
        <location filename="../src/settings.cpp" line="936"/>
        <location filename="../src/settings.cpp" line="1030"/>
        <location filename="../src/main.cpp" line="172"/>
        <location filename="../src/main.cpp" line="239"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="460"/>
        <location filename="../src/main.cpp" line="238"/>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation>Gjeldende kjerne støtter ikke Squashfs. Kan ikke fortsette.</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="57"/>
        <source>Failed to initialize configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="80"/>
        <source>Configuration validation failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="85"/>
        <source>Exception during initialization: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="88"/>
        <source>Unknown exception during initialization</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="119"/>
        <source>Could not create work directory. </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="143"/>
        <source>Could not create temp directory:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="144"/>
        <source>Please check that the parent directory exists and is writable:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="162"/>
        <source>Compression format &apos;%1&apos; is not supported by the current kernel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="168"/>
        <source>Invalid cores setting: %1. Must be between 1 and %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="174"/>
        <source>Invalid throttle setting: %1. Must be between 0 and 20</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="180"/>
        <source>Snapshot directory cannot be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="188"/>
        <source>Snapshot name cannot be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="194"/>
        <source>Snapshot name contains invalid characters: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="200"/>
        <source>Kernel version cannot be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="205"/>
        <source>Kernel file not found: /boot/vmlinuz-%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="211"/>
        <source>Kernel %1 doesn&apos;t support Squashfs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="235"/>
        <source>Exclusion file does not exist: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="244"/>
        <source>Unbalanced quotes in exclusion list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="269"/>
        <source>Insufficient free space: %1 KiB available, minimum %2 KiB required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="276"/>
        <source>Insufficient free space in work directory: %1 KiB available, minimum %2 KiB required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="291"/>
        <source>Failed to determine number of CPU cores</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="297"/>
        <source>Configuration file does not exist: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="298"/>
        <source>Using default settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="300"/>
        <source>Cannot read configuration file: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="301"/>
        <source>Error: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="311"/>
        <source>Required tool not found: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="320"/>
        <source>Required directory not found: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="339"/>
        <source>Initialization Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="340"/>
        <source>Failed to initialize application settings:

%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="451"/>
        <source>Could not find a usable kernel</source>
        <translation>Fant ingen brukbar kjerne</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="452"/>
        <source>Searched for kernel files in /boot/ but none were found or accessible.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="473"/>
        <source>No users found in the system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="476"/>
        <source>Failed to determine system information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="570"/>
        <source>Used space on / (root): </source>
        <translation>Brukt plass på / (rot):</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="573"/>
        <source>estimated</source>
        <translation>estimert</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="582"/>
        <source>Used space on /home: </source>
        <translation>Brukt plass på /home:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="638"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Ledig plass på %1, der mappa til ISO-bildet legges:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="642"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation>Det bør være nok ledig plass til de komprimerte dataene fra / og /home

    Hvis nødvendig så kan du frigjøre plass ved å
    fjerne gamle ISO-bilder og lagrede kopier:
    %1 ISO-bilder bruker %2 diskplass.
</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="656"/>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="657"/>
        <source>Documents</source>
        <translation>Dokumenter</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="658"/>
        <source>Downloads</source>
        <translation>Nedlastinger</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="659"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="660"/>
        <source>Music</source>
        <translation>Musikk</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="661"/>
        <source>Networks</source>
        <translation>Nettverk</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="662"/>
        <source>Pictures</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="664"/>
        <source>Videos</source>
        <translation>Videoer</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="813"/>
        <source>Error reading system configuration file: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="818"/>
        <source>Error accessing user configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="934"/>
        <location filename="../src/settings.cpp" line="1028"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation>Utfila %1 finnes allerede. Velg et annet filnavn eller slett eksisterende fil.</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="71"/>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="72"/>
        <location filename="../src/about.cpp" line="82"/>
        <source>Changelog</source>
        <translation>Endringslogg</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="73"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="95"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
</context>
<context>
    <name>Work</name>
    <message>
        <location filename="../src/work.cpp" line="116"/>
        <source>Cleaning...</source>
        <translation>Rengjøring …</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="130"/>
        <location filename="../src/work.cpp" line="320"/>
        <source>Done</source>
        <translation>Ferdig</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="142"/>
        <source>Interrupted or failed to complete</source>
        <translation>Avbrutt, eller klarte ikke fullføre</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="175"/>
        <location filename="../src/work.cpp" line="278"/>
        <location filename="../src/work.cpp" line="300"/>
        <location filename="../src/work.cpp" line="338"/>
        <location filename="../src/work.cpp" line="476"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="176"/>
        <source>There&apos;s not enough free space on your target disk, you need at least %1</source>
        <translation>Det er ikke nok ledig plass på måldisken. Det trengs minst %1</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="179"/>
        <source>You have %1 free space on %2</source>
        <translation>Det er %1 ledig plass på %2</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="182"/>
        <source>If you are sure you have enough free space rerun the program with -o/--override-size option</source>
        <translation>Kjør programmet på nytt med valget -o/--override-size hvis det er nok ledig diskplass</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="207"/>
        <source>Copying the new-iso filesystem...</source>
        <translation>Kopierer det nye ISO-filsystemet …</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="219"/>
        <source>Could not create temp directory. </source>
        <translation>Klarte ikke å opprette midlertidig mappe.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="275"/>
        <source>Squashing filesystem...</source>
        <translation>Pakker filsystemet …</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="279"/>
        <source>Could not create linuxfs file, please check /var/log/%1.log</source>
        <translation>Klarte ikke opprette linuxfs-fil. Undersøk /var/log/%1.log</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="297"/>
        <source>Creating CD/DVD image file...</source>
        <translation>Oppretter CD-/DVD-bildefil …</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="301"/>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation>Klarte ikke å opprette ISO-fil. Se etter om det er nok ledig plass på målpartisjonen.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="307"/>
        <source>Making hybrid iso</source>
        <translation>Lager hybrid-ISO</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="325"/>
        <source>Success</source>
        <translation>Vellykket</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="326"/>
        <source>MX Snapshot completed successfully!</source>
        <translation>Opprettet ISO-bilde</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="327"/>
        <source>Snapshot took %1 to finish.</source>
        <translation>Tidsbruk %1.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="328"/>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation>Takk for at du brukte MX ISO-bilde – nå kan du kjøre MX Live-USB.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="335"/>
        <source>Installing </source>
        <translation>Installerer</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="338"/>
        <source>Could not install </source>
        <translation>Klarte ikke å installere</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="348"/>
        <source>Calculating checksum...</source>
        <translation>Beregner sjekksum …</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="386"/>
        <source>Building new initrd...</source>
        <translation>Bygger ny initrd …</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="477"/>
        <source>Could not create working directory. </source>
        <translation>Klarte ikke å opprette arbeidsmappe.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="615"/>
        <source>Calculating total size of excluded files...</source>
        <translation>Beregner den totale størrelsen til utelukkede filer …</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="625"/>
        <source>Calculating size of root...</source>
        <translation>Beregner størrelsen til root …</translation>
    </message>
</context>
</TS>